@@ -82,7 +82,7 @@ def get_code(token_type):
 
 class SpellCheckPlugin:
     name = "flake8-spellcheck"
-    version = "0.20.0"
+    version = "0.20.1"
 
     def __init__(self, tree, filename="(none)", file_tokens=None):
         self.file_tokens = file_tokens
@@ -167,8 +167,9 @@ class SpellCheckPlugin:
         return (
             token_info.type == tokenize.COMMENT
             and "comments" in self.spellcheck_targets
-            # Ensure comment is non-empty, github.com/MichaelAquilina/flake8-spellcheck/issues/34
-            and token_info.string.strip() != "#"
+            # Ensure comment is neither empty nor a sequence of "#" characters
+            # github.com/MichaelAquilina/flake8-spellcheck/issues/34
+            and token_info.string.lstrip("#").strip() != ""
             # Ignore flake8 pragma comments
             and token_info.string.lstrip("#").split()[0] != "noqa:"
         )
